Config

Struct Config 

pub struct Config { /* private fields */ }
Abstracts the configuration of the application.

Implementations

Source

impl Config

pub fn new(args: Args) -> Result<Self, Box<dyn Error>>

Creates a new configuration for the application.

  • args are the command-line parameters consisting of the IP address and port to which the application should bind.
Errors

An error is returned if the number of arguments is incorrect or if parsing the arguments fails.